@@ -1,10 +1,10 @@
 package Module::Install::RDF;
 
 use 5.008;
-use base qw(Module::Install::Base);
+use parent qw(Module::Install::Base);
 use strict;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 our $AUTHOR_ONLY = 1;
 
 sub rdf_metadata
